//
//  tank
//
//  Import and Playlist Daemon for autoradio project
//
//
//  Copyright (C) 2017-2019 Christian Pointner <equinox@helsinki.at>
//
//  This file is part of tank.
//
//  tank is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  any later version.
//
//  tank is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with tank. If not, see <http://www.gnu.org/licenses/>.
//

package auth

import (
	"testing"
	"time"
)

var (
	testSecret = "secrettest"
)

//
// Testing
//

func TestCreateSessionManager(t *testing.T) {
	cfg := SessionsConfig{}
	if _, err := NewSessionManager(cfg); err != nil {
		t.Fatalf("unexpected error: %v", err)
	}
}

func TestSessionExpiry(t *testing.T) {
	cfg := SessionsConfig{}
	cfg.MaxAge = time.Second
	sm, err := NewSessionManager(cfg)
	if err != nil {
		t.Fatalf("unexpected error: %v", err)
	}

	s1 := &Session{Username: "test"}
	id, err := sm.insert(s1)
	if err != nil {
		t.Fatalf("unexpected error: %v", err)
	}

	s2 := sm.get(id)
	if s2 == nil {
		t.Fatalf("session-manager returned no session")
	}
	if s2.Expired() {
		t.Fatalf("session has already expired")
	}

	if s1.Username != s2.Username {
		t.Fatalf("sessions don't match")
	}

	time.Sleep(time.Second + 100*time.Millisecond)

	if !s2.Expired() {
		t.Fatalf("session hasn't expired in time")
	}
}
